AIDebugCameraPicture class

A camera picture exposed by the AI debugger's debug camera UI.

AIデバッガーのデバッグカメラUIに表示する画像です。

Annotations

Constructors

AIDebugCameraPicture({required String id, required String label})
Creates a camera picture for debug operations.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Identifier used to resolve the app's actual image provider.
final
label String
Label displayed in the AI debugger UI.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override